@@ -39,7 +39,7 @@
 
 name_suggest <- function(q=NULL, datasetKey=NULL, rank=NULL, fields=NULL, start=NULL, limit=100, ...){
   url <- paste0(gbif_base(), '/species/suggest')
-  args <- rgbif_compact(list(q=q, rank=rank, offset=start, limit=limit))
+  args <- rgbif_compact(list(q = q, rank = rank, offset = start, limit = limit))
   tt <- gbif_GET(url, args, FALSE, ...)
 
   if (is.null(fields)) {
@@ -64,11 +64,11 @@ name_suggest <- function(q=NULL, datasetKey=NULL, rank=NULL, fields=NULL, start=
     hier <- sapply(tt, function(x) x[ names(x) %in% "higherClassificationMap" ])
     hier <- unname(hier)
     names(hier) <- vapply(tt, "[[", numeric(1), "key")
-    list(data = df, hierarchy = hier)
+    list(data = tibble::as_data_frame(df), hierarchy = hier)
   } else {
     out <- lapply(tt, function(x) x[names(x) %in% toget])
     x <- data.table::setDF(data.table::rbindlist(out, use.names = TRUE, fill = TRUE))
-    x
+    tibble::as_data_frame(x)
   }
 }
 
