@@ -2,16 +2,15 @@
 #' codes.
 #'
 #' @export
-#'
-#' @param type Type of data, one of catalog_number, collection_code, collector_name,
-#' institution_code. Unique partial strings work too, like 'cat' for catalog_number
+#' @param type Type of data, one of catalogNumber, collectionCode, recordedBy, or
+#' institutionCode. Unique partial strings work too, like 'cat' for catalogNumber
 #' @param q Search term
 #' @param limit Number of results, default=5
 #' @param pretty Pretty as true (Default) uses cat to print data, FALSE gives
 #' character strings.
 #' @param ... Further named parameters, such as \code{query}, \code{path}, etc, passed on to
-#' \code{\link[httr]{modify_url}} within \code{\link[httr]{GET}} call. Unnamed parameters will be
-#' combined with \code{\link[httr]{config}}.
+#' \code{\link[httr]{modify_url}} within \code{\link[httr]{GET}} call. Unnamed parameters
+#' will be combined with \code{\link[httr]{config}}.
 #'
 #' @references \url{http://www.gbif.org/developer/occurrence#search}
 #'
@@ -25,6 +24,9 @@
 #' # institution code
 #' occ_metadata(type = "institutionCode", q='GB')
 #'
+#' # recorded by
+#' occ_metadata(type = "recordedBy", q='scott')
+#'
 #' # data as character strings
 #' occ_metadata(type = "catalogNumber", q=122, pretty=FALSE)
 #'
@@ -40,15 +42,15 @@
 #' # occ_metadata(type = "cat", q=122, config=progress())
 #' }
 
-occ_metadata <- function(type = "catalogNumber", q=NULL, limit=5, pretty=TRUE, ...)
-{
-  type <- match.arg(type, c("catalogNumber","collectionCode","collectorName","institutionCode"))
+occ_metadata <- function(type = "catalogNumber", q=NULL, limit=5, pretty=TRUE, ...) {
+  type <- match.arg(type, c("catalogNumber", "collectionCode", "recordedBy", "institutionCode"))
   url <- sprintf('%s/occurrence/search/%s', gbif_base(), type)
   args <- rgbif_compact(list(q = q, limit = limit))
   out <- gbif_GET(url, args, TRUE, ...)
 
-  if(pretty)
-    cat(out, sep="\n")
-  else
+  if (pretty) {
+    cat(out, sep = "\n")
+  } else {
     out
+  }
 }
