@@ -27,10 +27,9 @@
 parsenames <- function(scientificname, ...) {
   url <- paste0(gbif_base(), "/parser/name")
   tt <- POST(url, c(add_headers('Content-Type' = 'application/json')), ...,
-             body=jsonlite::toJSON(scientificname), make_rgbif_ua())
+             body = jsonlite::toJSON(scientificname), make_rgbif_ua())
   stop_for_status(tt)
-  stopifnot(tt$headers$`content-type`=='application/json')
-  temp <- content(tt, as = 'text', encoding = "UTF-8")
-  res <- jsonlite::fromJSON(temp, FALSE)
-  do.call(rbind_fill, lapply(res, as.data.frame))
+  stopifnot(tt$headers$`content-type` == 'application/json')
+  res <- jsonlite::fromJSON(c_utf8(tt), FALSE)
+  (x <- data.table::setDF(data.table::rbindlist(res, fill = TRUE, use.names = TRUE)))
 }
