@@ -17,11 +17,6 @@ test_that("returns the correct class", {
 
   # returns the correct value
   expect_equal(na.omit(tt$data$kingdom)[[2]], "Animalia")
-
-  # returns the correct dimensions
-  expect_equal(nrow(tt$data), 100)
-
-  expect_equal(NCOL(uu), 35)
 })
 
 test_that("works with habitat parameter", {
